      SUBROUTINE EIGOUT(NC,NR,LM,A,B)
      IMPLICIT REAL*8 (A-H,O-Z)
      double precision A(LM,NC),B(NC)
c
c Procedura drukuje macierz wektorow wlasnych (zapamietanych w macierzy A
c kolumnami) oraz odpowiadajace im wartosci wlasne (wektor B) stronami po
c 6 kolumn tak, ze wartosc wlasna znajduje sie nad kolumna odpowiadajaca 
c danemu wektorowi wlasnemu. Znaczenie innych parametrow jest nastepujace:
c
c NC - liczba drukowanych wektorow wlasnych (kolumn macierzy A) oraz
c      wartosci wlasnych.
c NR - faktyczny wymiar wierszowy macierzy A (tj. liczba drukowanych wierszy.
c LM - wymiar wierszowy macierzy A w segmencie wywolujacym procedure.
c
      KA=1                                                              
      KC=6                                                              
    1 KB=MIN0(KC,NC)                                                    
      WRITE(IOUT,600) (I,I=KA,KB)                                          
      WRITE(IOUT,601) (B(I),I=KA,KB)                                       
      WRITE(IOUT,602)                                                      
    2 N=0                                                               
      DO 3  I=1,NR                                                      
      WRITE(IOUT,603) I,(A(I,J),J=KA,KB)                                   
      N=N+1                                                             
      IF(N.LT.10) GO TO 3                                               
      WRITE(IOUT,602)                                                      
      N=0                                                               
    3 CONTINUE                                                          
    4 IF (KB.EQ.NC) RETURN                                              
      KA=KC+1                                                           
      KC=KC+6                                                           
      GO TO 1                                                           
  600 FORMAT (// 9H ROOT NO.,I4,9I11)                                   
  601 FORMAT (/5X,10(1PE11.4))                                              
  602 FORMAT (2H  )                                                     
  603 FORMAT (I5,10F11.5)                                               
  604 FORMAT (1H1)                                                      
      END
